/*
 * \file Loads.c
 * \brief: implementation of the Loads class, derived from DataSet class
 */

/*Headers: {{{1*/
#ifdef HAVE_CONFIG_H
	#include "config.h"
#else
#error "Cannot compile with HAVE_CONFIG_H symbol! run configure first!"
#endif

#include <vector>
#include <functional>
#include <algorithm>
#include <iostream>

#include "./DataSet.h"
#include "../shared/shared.h"
#include "../include/include.h"
#include "../EnumDefinitions/EnumDefinitions.h"

using namespace std;
/*}}}*/

/*Object constructors and destructor*/
/*FUNCTION Loads::Loads(){{{1*/
Loads::Loads(){
	return;
}
/*}}}*/
/*FUNCTION Loads::Loads(int in_enum){{{1*/
Loads::Loads(int in_enum): DataSet(in_enum){
	//do nothing;
	return;
}
/*}}}*/
/*FUNCTION Loads::~Loads(){{{1*/
Loads::~Loads(){
	return;
}
/*}}}*/

/*Numerics:*/
/*FUNCTION Loads::NumberOfLoads{{{1*/
int Loads::NumberOfLoads(void){

	int localloads=0;
	int numberofloads=0;

	/*Get number of local loads*/
	localloads=this->Size();

	/*figure out total number of loads combining all the cpus (no clones here)*/
	#ifdef _PARALLEL_
	MPI_Reduce(&localloads,&numberofloads,1,MPI_INT,MPI_SUM,0,MPI_COMM_WORLD );
	MPI_Bcast(&numberofloads,1,MPI_INT,0,MPI_COMM_WORLD);
	#else
	numberofloads=localloads;
	#endif

	return numberofloads;
}
/*}}}*/
/*FUNCTION Loads::OutputRifts{{{1*/
void  Loads::OutputRifts(Vec riftproperties){

	int i;

	for(i=0;i<this->Size();i++){

		Object* object=(Object*)this->GetObjectByOffset(i);

		if(object->Enum()==RiftfrontEnum){

			Riftfront* riftfront=(Riftfront*)object;
			riftfront->OutputProperties(riftproperties);
		}
	}
}
/*}}}*/
